@@ -3,7 +3,9 @@
 from pycodehash.python_function.decorator_stripper import DecoratorStripper
 from pycodehash.python_function.docstring_stripper import DocstringStripper
 from pycodehash.python_function.function_stripper import FunctionStripper
-from pycodehash.python_function.lines_transformer import LinesTransformer
+from pycodehash.python_function.ruff_processor import RuffProcessor
+from pycodehash.python_function.ruff_project_processor import RuffProjectProcessor
+from pycodehash.python_function.source_processor import ProjectSourceProcessor, SourceProcessor
 from pycodehash.python_function.typehint_stripper import TypeHintStripper
 from pycodehash.python_function.whitespace_normalizer import WhitespaceNormalizer
 
@@ -13,5 +15,8 @@ __all__ = [
     "TypeHintStripper",
     "FunctionStripper",
     "DecoratorStripper",
-    "LinesTransformer",
+    "SourceProcessor",
+    "RuffProcessor",
+    "RuffProjectProcessor",
+    "ProjectSourceProcessor",
 ]
